@@ -4,34 +4,34 @@
 #'
 #' @param parameter type of parameter to download
 #' \itemize{
-#'  \item{"BEN"}{ - Benceno}
-#'  \item{"CH4"}{ - Metano}
-#'  \item{"CN"}{ - Carbono negro}
-#'  \item{"CO"}{ - Monóxido de carbono}
-#'  \item{"CO2"}{ - Dióxido de carbono}
-#'  \item{"DV"}{ - Dirección del viento}
-#'  \item{"H2S"}{ - Acido Sulfhídrico}
-#'  \item{"HCNM"}{ - Hidrocarburos no metánicos}
-#'  \item{"HCT"}{ - Hidrocarburos Totales}
-#'  \item{"HR"}{ - Humedad relativa}
-#'  \item{"HRI"}{ - Humedad relativa interior}
-#'  \item{"IUV"}{ - Índice de radiación ultravioleta}
-#'  \item{"NO"}{ - Óxido nítrico}
-#'  \item{"NO2"}{ - Dióxido de nitrógeno}
-#'  \item{"NOx"}{ - Óxidos de nitrógeno}
-#'  \item{"O3"}{ - Ozono}
-#'  \item{"PB"}{ - Presión Barométrica}
-#'  \item{"PM10"}{ - Partículas menores a 10 micras}
-#'  \item{"PM2.5"}{ - Partículas menores a 2.5 micras}
-#'  \item{"PP"}{ - Precipitación pluvial}
-#'  \item{"PST"}{ - Partículas Suspendidas totales}
-#'  \item{"RS"}{ - Radiación solar}
-#'  \item{"SO2"}{ - Dióxido de azufre}
-#'  \item{"TMP"}{ - Temperatura}
-#'  \item{"TMPI"}{ - Temperatura interior}
-#'  \item{"UVA"}{ - Radiación ultravioleta A}
-#'  \item{"VV"}{ - Radiación ultravioleta B}
-#'  \item{"XIL"}{ - Xileno}
+#'  \item BEN - Benceno
+#'  \item CH4 - Metano
+#'  \item CN - Carbono negro
+#'  \item CO - Monóxido de carbono
+#'  \item CO2 - Dióxido de carbono
+#'  \item DV - Dirección del viento
+#'  \item H2S - Acido Sulfhídrico
+#'  \item HCNM - Hidrocarburos no metánicos
+#'  \item HCT - Hidrocarburos Totales
+#'  \item HR - Humedad relativa
+#'  \item HRI - Humedad relativa interior
+#'  \item IUV - Índice de radiación ultravioleta
+#'  \item NO - Óxido nítrico
+#'  \item NO2 - Dióxido de nitrógeno
+#'  \item NOx - Óxidos de nitrógeno
+#'  \item O3 - Ozono
+#'  \item PB - Presión Barométrica
+#'  \item PM10 - Partículas menores a 10 micras
+#'  \item PM2.5 - Partículas menores a 2.5 micras
+#'  \item PP - Precipitación pluvial
+#'  \item PST - Partículas Suspendidas totales
+#'  \item RS - Radiación solar
+#'  \item SO2 - Dióxido de azufre
+#'  \item TMP - Temperatura
+#'  \item TMPI - Temperatura interior
+#'  \item UVA - Radiación ultravioleta A
+#'  \item VV - Radiación ultravioleta B
+#'  \item XIL - Xileno
 #' }
 #' @param start_date start of range in YYYY-MM-DD format
 #' @param end_date end of range from which to download data in YYYY-MM-DD format
@@ -41,10 +41,10 @@
 #' recommended that you use a more complicated statistical procedure to remove outliers.
 #' @param type The type of data to download. One of the following:
 #' \itemize{
-#'  \item{"Crude"}{ - Crude data that has not been validated}
-#'  \item{"Manual"}{ - Manually collected data that is sent to an external
+#'  \item Crude - Crude data that has not been validated
+#'  \item Manual - Manually collected data that is sent to an external
 #'  lab for analysis (may no be collected daily). Mostly used for suspend particles collected by
-#'  pushing air through a filter which is later sent to a lab to be weighted}
+#'  pushing air through a filter which is later sent to a lab to be weighted
 #'  }
 #'
 #' @return data.frame with a column named \emph{value} containing the air quality parameter values.
@@ -52,7 +52,7 @@
 #' date. Care should be taken when working with hourly data since
 #' each station has their own timezone (available in the \code{\link{stations_sinaica}} data.frame)
 #' and some stations reported the timezome in which they are located erroneously.
-#' @importFrom httr POST http_error content add_headers
+#' @importFrom httr POST http_error content add_headers with_config config
 #' @importFrom jsonlite fromJSON
 #' @importFrom dplyr left_join
 #' @importFrom utils data
@@ -107,12 +107,13 @@ sinaica_param_data <- function(parameter,
     where  = paste0("parametro = '", parameter, "' and fecha >= '", start_date,
                     "' and fecha <= '", end_date, "'")
   )
-
-  result <- POST(url,
-                 add_headers("user-agent" =
-                               "https://github.com/diegovalle/rsinaica"),
-                 body = fd,
-                 encode = "form")
+  result <- httr::with_config(httr::config(ssl_verifypeer = 0L), {
+    POST(url,
+         add_headers("user-agent" =
+                       "https://github.com/diegovalle/rsinaica"),
+         body = fd,
+         encode = "form")
+  })
   if (http_error(result))
     stop(sprintf("The request to <%s> failed [%s]",
                  url,
