@@ -3,6 +3,7 @@ context("test-sinaica_param_data.R")
 test_that("sinaica_param_data works", {
   skip_on_cran()
 
+  skip("skip large downloads")
   # Errors
   expect_error(sinaica_param_data("ERROR", "2017-01-01", "2017-01-31"),
                "parameter should be one of: BEN, CH4")
@@ -21,16 +22,15 @@ test_that("sinaica_param_data works", {
                "The maximum amount of data you can download is 1 month")
 
   df <- sinaica_param_data("O3", "2015-10-14", "2015-10-14")
-  expect_equal(df$value[1:10], c(0.0066721, 0.014782, 0.011957,
-                                 0.0021908, 0.0027581, 0.0063391,
-                                 0.0089907, 0.0051245, 0.0018884, 0.0029096))
+  expect_equal(df$value[1:10], c(0.019, 0.018, 0.007, 0.009, 0.009, 0.012,
+                                 0.006, 0.003, 0.004,
+                                 0.01))
 
   df <- sinaica_param_data("O3", "2015-10-14", "2015-10-14",
                            remove_extremes = FALSE)
-  expect_equal(df$value[1:10], c(0.0066721, 0.014782, 0.011957,
-                                    0.0021908, 0.0027581, 0.0063391,
-                                    0.0089907, 0.0051245, 0.0018884,
-                                    0.0029096))
+  expect_equal(df$value[1:10], c(0.019, 0.018, 0.007, 0.009, 0.009,
+                                 0.012, 0.006, 0.003, 0.004,
+                                 0.01))
   expect_equal(names(df), c("id", "station_id", "station_name",
                             "station_code", "network_name",
                             "network_code", "network_id",
